@@ -36,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "21.05.0"
+#define POPPLER_VERSION "21.07.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -117,11 +117,6 @@
 #define USE_BOOST_HEADERS 1
 #endif
 
-/* Is splash backend available */
-#ifndef HAVE_SPLASH
-#define HAVE_SPLASH 1
-#endif
-
 //------------------------------------------------------------------------
 // version
 //------------------------------------------------------------------------
